@@ -29,6 +29,7 @@ class WindowList(Dmenu):
     defaults = [
         ("item_format", "{group}.{id}: {window}", "the format for the menu items"),
         ("all_groups", True, "If True, list windows from all groups; otherwise only from the current group"),
+        ("dmenu_lines", "80", "Give lines vertically. Set to None get inline"),
     ]
 
     def __init__(self, **config):
@@ -43,9 +44,9 @@ class WindowList(Dmenu):
         self.item_to_win = {}
 
         if self.all_groups:
-            windows = self.qtile.windowMap.values()
+            windows = self.qtile.windows_map.values()
         else:
-            windows = self.qtile.currentGroup.windows
+            windows = self.qtile.current_group.windows
 
         for win in windows:
             if win.group:
@@ -56,7 +57,7 @@ class WindowList(Dmenu):
 
     def run(self):
         self.list_windows()
-        out = super(WindowList, self).run(items=self.item_to_win.keys())
+        out = super().run(items=self.item_to_win.keys())
 
         try:
             sout = out.rstrip('\n')
@@ -72,6 +73,6 @@ class WindowList(Dmenu):
             # The selected window got closed while the menu was open?
             return
 
-        screen = self.qtile.currentScreen
-        screen.setGroup(win.group)
+        screen = self.qtile.current_screen
+        screen.set_group(win.group)
         win.group.focus(win)
