@@ -27,8 +27,6 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from __future__ import division
-
 import math
 
 from .base import _SimpleLayoutBase
@@ -40,7 +38,7 @@ COLROW = 2  # do cols top to bottom, left to right
 GOLDEN_RATIO = 1.618
 
 
-class GridInfo(object):
+class GridInfo:
     """
     Calculates sizes for grids
     >>> gi = GridInfo(.5, 5, 600, 480)
@@ -233,7 +231,7 @@ class RatioTile(_SimpleLayoutBase):
 
     def add(self, w):
         self.dirty = True
-        self.clients.appendHead(w)
+        self.clients.append_head(w)
 
     def remove(self, w):
         self.dirty = True
@@ -276,9 +274,9 @@ class RatioTile(_SimpleLayoutBase):
             return
         x, y, w, h = self.layout_info[idx]
         if win.has_focus:
-            bc = self.group.qtile.colorPixel(self.border_focus)
+            bc = self.group.qtile.color_pixel(self.border_focus)
         else:
-            bc = self.group.qtile.colorPixel(self.border_normal)
+            bc = self.group.qtile.color_pixel(self.border_normal)
         win.place(
             x,
             y,
@@ -301,7 +299,7 @@ class RatioTile(_SimpleLayoutBase):
     def shuffle(self, function):
         if self.clients:
             function(self.clients)
-            self.group.layoutAll()
+            self.group.layout_all()
 
     cmd_down = _SimpleLayoutBase.previous
     cmd_up = _SimpleLayoutBase.next
@@ -312,20 +310,20 @@ class RatioTile(_SimpleLayoutBase):
     def cmd_shuffle_down(self):
         if self.clients:
             self.clients.rotate_up()
-            self.self.group.layoutAll()
+            self.self.group.layout_all()
 
     def cmd_shuffle_up(self):
         if self.clients:
             self.clients.rotate_down()
-            self.self.group.layoutAll()
+            self.self.group.layout_all()
 
     def cmd_decrease_ratio(self):
         new_ratio = self.ratio - self.ratio_increment
         if new_ratio < 0:
             return
         self.ratio = new_ratio
-        self.group.layoutAll()
+        self.group.layout_all()
 
     def cmd_increase_ratio(self):
         self.ratio += self.ratio_increment
-        self.group.layoutAll()
+        self.group.layout_all()
